@@ -1,6 +1,6 @@
 from __future__ import annotations
 
-from typing import TYPE_CHECKING, Callable
+from typing import TYPE_CHECKING
 
 import pytest
 
@@ -12,9 +12,12 @@ from tox.session.cmd.list_env import list_env
 from tox.session.cmd.quickstart import quickstart
 from tox.session.cmd.run.parallel import run_parallel
 from tox.session.cmd.run.sequential import run_sequential
+from tox.session.cmd.schema import gen_schema
 from tox.session.cmd.show_config import show_config
 
 if TYPE_CHECKING:
+    from collections.abc import Callable
+
     from tox.session.state import State
 
 
@@ -23,6 +26,7 @@ def core_handlers() -> dict[str, Callable[[State], int]]:
     return {
         "config": show_config,
         "c": show_config,
+        "schema": gen_schema,
         "list": list_env,
         "l": list_env,
         "run": run_sequential,
