@@ -3,6 +3,8 @@ from __future__ import annotations
 from types import SimpleNamespace
 from typing import TYPE_CHECKING
 
+import pytest
+
 from tox import __version__
 from tox.plugin.manager import MANAGER
 
@@ -48,3 +50,29 @@ def test_version_with_plugin(tox_project: ToxProjectCreator, mocker: MockFixture
         "    B-1.0 at B-path magic",
         "    A-2.0 at A-path",
     ]
+
+
+@pytest.mark.plugin_test
+def test_version_with_inline_plugin(tox_project: ToxProjectCreator) -> None:
+    def plugin() -> None:  # pragma: no cover
+        pass
+
+    project = tox_project({"tox.ini": "", "toxfile.py": plugin})
+    outcome = project.run("--version")
+    outcome.assert_success()
+    assert __version__ in outcome.out
+    assert "inline plugin:" in outcome.out
+    assert "toxfile.py" in outcome.out
+
+
+@pytest.mark.plugin_test
+def test_version_with_inline_plugin_append_version_info(tox_project: ToxProjectCreator) -> None:
+    def plugin() -> None:  # pragma: no cover
+        def tox_append_version_info() -> str:
+            return "custom-info-v1"
+
+    project = tox_project({"tox.ini": "", "toxfile.py": plugin})
+    outcome = project.run("--version")
+    outcome.assert_success()
+    assert "inline plugin:" in outcome.out
+    assert "custom-info-v1" in outcome.out
